eml.types package
=================

Classes with no predefine Principal Tag
---------------------------------------

_NoTagObject Base Class
~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eml.types.no_tag_object
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: eml.types.no_tag_object._NoTagObject
   :members:
   :undoc-members:
   :show-inheritance:

Extension String Class
~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eml.types.extension_string
   :members:
   :undoc-members:
   :show-inheritance:

Extension URI Class
~~~~~~~~~~~~~~~~~~~

.. automodule:: eml.types.extension_uri
   :members:
   :undoc-members:
   :show-inheritance:

i18n String Class
~~~~~~~~~~~~~~~~~

.. automodule:: eml.types.i18n_string
   :members:
   :undoc-members:
   :show-inheritance:

TextType Class
~~~~~~~~~~~~~~

.. automodule:: eml.types.text_type
   :members:
   :undoc-members:
   :show-inheritance:

Responsible Party Class
~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eml.types.responsible_party
   :members:
   :undoc-members:
   :show-inheritance:

Semantic Annotation Class
~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eml.types.semantic_annotation
   :members:
   :undoc-members:
   :show-inheritance:

Classes with predefine Principal Tag
------------------------------------

Section Class
~~~~~~~~~~~~~

.. automodule:: eml.types.section
   :members:
   :undoc-members:
   :show-inheritance:

Individual Name Class
~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eml.types.individual_name
   :members:
   :undoc-members:
   :show-inheritance:

Organization Name Class
~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eml.types.organization_name
   :members:
   :undoc-members:
   :show-inheritance:

Position Name Class
~~~~~~~~~~~~~~~~~~~

.. automodule:: eml.types.position_name
   :members:
   :undoc-members:
   :show-inheritance:

Address Class
~~~~~~~~~~~~~

.. automodule:: eml.types.address
   :members:
   :undoc-members:
   :show-inheritance:

Phone Class
~~~~~~~~~~~

.. automodule:: eml.types.phone
   :members:
   :undoc-members:
   :show-inheritance:
